disabled property
Whether the button is disabled.
When true, the icon colour is dimmed and tapping the button calls
disabledOnTap instead of the normal clock-out flow.
Implementation
final bool disabled;
Whether the button is disabled.
When true, the icon colour is dimmed and tapping the button calls
disabledOnTap instead of the normal clock-out flow.
final bool disabled;