disabledOnTap property

dynamic Function(BuildContext context)? disabledOnTap
final

Callback invoked when the button is tapped while disabled is true.

Use this to show a message or perform an alternative action when the button cannot be used.

Implementation

final Function(BuildContext context)? disabledOnTap;